
# q-expansion of newform 256.12.a.l, downloaded from the LMFDB on 11 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 256
weight = 12
poly_data = [17099916310116, -1034018012664, -244021939416, 7141379724, 904265037, -119616, -59846, -4, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[154031009306967957813222, 436760987706169512572712, -6076691518184755388034, -1035618262279216286002, -9484972946952452, 69178122788782986, 7198449043742, -1161742031108], 72513668910189874525005], [[-17200282765855949852713137924, -22067504294867245980180048, 272552362448142484551348, 52969016655801298253332, 119557996801112263320, -3539639436738357364, -3024673706738284, 59911076412152], 72513668910189874525005], [[272606013608805956202391661616, -23343275037519874505065327524, -1491731273923308386440582302, 105643477092517923182179524, 139006690515689043897639, -7017974681379231918892, -2993975817085108079, 117502379003839196], 11747214363450759673050810], [[-1224942989833616207311798272, -600909054219919419280146432, 24890128458484758069387264, 4241892402295669907464192, 38850449190717243392, -283353590942855110656, -29484847283167232, 4758495359418368], 72513668910189874525005], [[-2565634002761762612302725807552, -90767985305831894401592373396, 22045198128540513579381011994, 1080211926108383861914257060, -1050870089375631486003897, -71903786313742372833308, 10552362709102148873, 1200816651051572764], 11747214363450759673050810], [[5358950510392000555090871256, -4611068129001618826829754264, 77153253874026983106814188, 29835733178716520443290624, 9954446123574586265284, -1983395462131741683192, -420867928155122304, 33183147447505456], 217541006730569623575015], [[252750570140026785397423499712, 205529851015634079215261267904, -2862446089359581879936714544, -487149725686446280128738096, 2806916161127749667840, 31997945265557121032752, 3132599337410388752, -533415586048791456], 1957869060575126612175135]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0], [-124, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0], [0, 0, 0, -1, 1, -1, 0, 0], [-98676, 139, 0, 0, 0, 0, 0, 1], [0, 0, 0, 128, -1, 5, 3, 0], [-94710, 6822, 1, 0, 0, 0, 0, -8], [-581788, -9007, -32, 0, 0, 0, 0, 3], [0, 0, 0, -1301, -438, 111, -186, 0], [0, 0, 0, -3007, -1320, 1200, 336, 0], [0, 0, 0, -9134, 1707, -266, 246, 0], [0, 0, 0, -16504, 403, 6593, 1191, 0], [-280912746, 433244, 538, 0, 0, 0, 0, 552], [-257670580, -949309, -704, 0, 0, 0, 0, 330], [0, 0, 0, -108496, 24063, 8124, -4782, 0], [0, 0, 0, 203294, 65973, 27615, -2247, 0], [-2265544212, 1081563, 20768, 0, 0, 0, 0, -2392], [0, 0, 0, -162996, -141425, -74979, 25899, 0], [9314084740, -9433639, 6976, 0, 0, 0, 0, -8805], [0, 0, 0, -277735, -613950, -4011, -18726, 0], [-3038864354, -39791530, 34825, 0, 0, 0, 0, -15552], [0, 0, 0, 2899154, 557522, 238562, -65640, 0], [271167588, 46850553, -101088, 0, 0, 0, 0, 45216], [-20618801682, -50802154, -166231, 0, 0, 0, 0, 42592], [10710149434, -144117770, -131911, 0, 0, 0, 0, 53784], [0, 0, 0, -3233890, -2014287, 1202043, -234627, 0], [0, 0, 0, 8824797, 1572122, -1071159, -309534, 0], [33022651980, 38464683, 445952, 0, 0, 0, 0, 74087], [0, 0, 0, -14333047, 2597052, 1001636, 591612, 0], [-18824299854, -157869688, 417836, 0, 0, 0, 0, -146960], [0, 0, 0, 24144110, -10037097, -910798, -132378, 0], [-282038673660, 148005737, -69376, 0, 0, 0, 0, -346079], [325497222294, 13549844, 2540110, 0, 0, 0, 0, 289080], [28469859340, -161548365, -1178880, 0, 0, 0, 0, 55530], [0, 0, 0, -89953521, 1099002, -10668858, -394710, 0], [0, 0, 0, -68543541, -15078574, 19588719, -1442058, 0], [0, 0, 0, -14127794, 20963649, -17758493, 3701205, 0], [-221295577276, -1986697823, 530816, 0, 0, 0, 0, 1862454], [0, 0, 0, -130501453, -6116823, -26892189, -7263864, 0], [0, 0, 0, -252486694, -35674263, 8189667, 8310357, 0], [605942915748, -2718733223, 7520416, 0, 0, 0, 0, -2682790], [0, 0, 0, -125171819, 29447984, 25043560, -7273128, 0], [0, 0, 0, 60654238, 109524387, -24882414, 1559982, 0], [1737875859674, 2749990422, 2521449, 0, 0, 0, 0, -5912232], [0, 0, 0, 265812543, 34814838, 54946290, 2816094, 0], [0, 0, 0, 423819059, -50060209, -37071205, 3925788, 0], [-3477523768988, 1133219369, -2061728, 0, 0, 0, 0, -2266290], [0, 0, 0, -358629226, 67857465, -55037854, 25538226, 0], [-8590183266108, -10080214639, -9407936, 0, 0, 0, 0, 5175480], [0, 0, 0, -206027473, -10476354, -124117078, -35348634, 0], [1687803559038, -15774761530, -42092943, 0, 0, 0, 0, 10441760], [0, 0, 0, -974465618, -81805422, -101338770, 46928544, 0], [-3621764189590, 3176364918, -25574919, 0, 0, 0, 0, -21119016], [-7700153805972, 21921032731, 44906400, 0, 0, 0, 0, -4749596], [-3456419993694, -26206735400, 17942628, 0, 0, 0, 0, -2281328], [0, 0, 0, -1088721219, 274464264, 241814145, 11746470, 0], [0, 0, 0, -1287391245, 29942646, 407969394, -46764066, 0], [0, 0, 0, -2214486972, -280772945, -96434016, -20256630, 0], [0, 0, 0, -921131050, -190765227, 15989567, 65554137, 0], [3598985695470, -1819401434, -42371327, 0, 0, 0, 0, 13615520], [-22605309666260, 21836851491, 85617888, 0, 0, 0, 0, -14434209], [0, 0, 0, 509105903, -877668450, 760628730, -979818, 0], [-30969338193884, 35298411329, -34709216, 0, 0, 0, 0, -7597797], [0, 0, 0, 6622500857, -235937313, -455296167, -151523568, 0], [-25757541124378, 35281417180, -63587494, 0, 0, 0, 0, 7900584], [0, 0, 0, 3353080041, -1457820504, 828861984, 29183328, 0], [-55943776954100, -110284397189, -22837696, 0, 0, 0, 0, -90835653], [46357156614226, 1158808232, 264168028, 0, 0, 0, 0, 12198096], [-58967684572884, 59826836283, 140372000, 0, 0, 0, 0, 37526234], [0, 0, 0, -9503069717, -1050644470, -1346830538, -372739782, 0], [-12146013166686, 63348385728, -196596832, 0, 0, 0, 0, -75595168], [0, 0, 0, 6985055477, 1754486070, -722902287, 503505402, 0], [0, 0, 0, -9887698164, -458739551, 473944752, -646413450, 0], [0, 0, 0, -2540785520, 2495701039, -1498624067, 396891531, 0], [-36367154970004, 149511306091, 233239136, 0, 0, 0, 0, 100914726], [0, 0, 0, -2696652056, -4562430132, 627261432, -199725672, 0], [0, 0, 0, -631227376, -7950819693, 3355103409, 112082487, 0], [0, 0, 0, 19289342353, 845522988, 841587892, -244034196, 0], [-65796908597238, 353433606, 627459217, 0, 0, 0, 0, -24509192], [32834021724742, -55245905476, -321023318, 0, 0, 0, 0, 132335400], [-139673183537724, 5478773897, -643459456, 0, 0, 0, 0, 256227151], [0, 0, 0, -30128886955, -3381347876, -489095116, -709931796, 0], [0, 0, 0, -1408424582, -9342593916, 206483538, 617526084, 0], [-51816263378006, -178131532554, -1542954951, 0, 0, 0, 0, -14840424], [0, 0, 0, -15085147431, 1004559591, 1056550617, 1053995520, 0], [273001272877164, 248286839395, -74798368, 0, 0, 0, 0, 100702533], [-12426029540454, -815759848474, 603200737, 0, 0, 0, 0, -523992072], [-151936510989002, 218215034620, -33990262, 0, 0, 0, 0, 377284008], [0, 0, 0, 8847389331, 11832257142, -3651574878, 507523374, 0], [0, 0, 0, -44189473462, 3565283366, 1944135242, -1114114944, 0], [72693609786852, 578107360577, 237567136, 0, 0, 0, 0, 594453933], [0, 0, 0, 61867839198, 1740921165, -6814811430, -568835334, 0], [0, 0, 0, -28258936457, -9046389353, -6760862129, 502934340, 0], [346071110239692, 612693264947, -398868096, 0, 0, 0, 0, 375807596], [757956102971428, 42954831689, -606926624, 0, 0, 0, 0, 143440188], [0, 0, 0, 22479202159, 8920568022, -8227318989, -1371599706, 0], [0, 0, 0, -18491554070, 5295322725, 757824783, 1317634953, 0], [211514827943574, -566034441932, 1729700862, 0, 0, 0, 0, 335542456], [119638536098444, 376457753179, -411130048, 0, 0, 0, 0, -68663349], [0, 0, 0, 20265681376, -11317159429, -632150543, 4431066999, 0], [436125902259908, 1977244697449, -3635216512, 0, 0, 0, 0, 455307171], [0, 0, 0, -138067942368, 25452577287, 7573469373, -3900569589, 0], [-18711063859164, 257502412449, 985370912, 0, 0, 0, 0, -675077113], [755712725745030, 2679515725428, -202921250, 0, 0, 0, 0, -1284267848], [338693433809260, 1221779350403, -3370311584, 0, 0, 0, 0, -955613631], [-578009336116382, 565199962040, -241769036, 0, 0, 0, 0, 1101900336], [1653012762127116, 412578160715, -549035648, 0, 0, 0, 0, -495962571], [-651428216598606, 1394720859632, 5628584744, 0, 0, 0, 0, 116941408], [0, 0, 0, 192607683961, 65397517557, 13141902417, -4026558396, 0], [-119756177879378, 448338709926, -9789640767, 0, 0, 0, 0, -263934720], [0, 0, 0, -56600012168, 7871084138, -16206098336, 794209500, 0], [0, 0, 0, 1858685637, -17400606916, 3500783412, -7846122516, 0], [1057569449460606, 216094893062, 3282003921, 0, 0, 0, 0, 4249496000], [-176072077994420, 3385021914843, 1293549504, 0, 0, 0, 0, -159088515], [0, 0, 0, 37880108095, 11986054550, -31281947453, -11631664698, 0], [-2660012296903782, 2788784314102, 2579490105, 0, 0, 0, 0, 44759128], [205770240461060, 592866220729, 9166588352, 0, 0, 0, 0, 3139763019], [0, 0, 0, 140494732469, 77148088620, 21431748777, 10264591086, 0], [0, 0, 0, -155715074505, 98099933802, -32313963954, -2226079902, 0], [-2115616479784476, 499780888121, -2967104224, 0, 0, 0, 0, -1660345124], [0, 0, 0, -71107206663, 42415815932, 2903163036, -2434373820, 0], [1129844499836218, -4644384564314, 2148341633, 0, 0, 0, 0, -5127648840], [0, 0, 0, -124617991148, -37137189585, 6901481301, 14147327283, 0], [-895155056750772, 4202499143027, 10139295744, 0, 0, 0, 0, -3698365720], [-1010131368741724, -685785588039, -13178843232, 0, 0, 0, 0, 3317274390], [0, 0, 0, -173897674356, 89491162911, -48350971011, 3814741707, 0], [0, 0, 0, 409787728300, 76293135679, 59280028261, 3369901731, 0], [0, 0, 0, 456519019302, -94804719276, 70065276846, 1856515020, 0], [0, 0, 0, -13551620919, -208094780427, 97461611745, 10428741156, 0], [0, 0, 0, -135754465183, -140694886440, 5567131616, 9240562848, 0], [204732432944836, -3840631769807, 15307873088, 0, 0, 0, 0, -6334780932], [0, 0, 0, -316488470401, 130837264875, -88720835193, 3061832076, 0], [0, 0, 0, -79854276518, 97363717304, -6067868990, 15346695324, 0], [0, 0, 0, -259717095369, 90431780698, -4745904810, 14762894106, 0], [3397063760229798, 6023499392220, 122174682, 0, 0, 0, 0, -4384043736], [-3695656404954406, 4028654505350, 7498588369, 0, 0, 0, 0, -613824072], [0, 0, 0, 436084941224, -125628069, -86719311687, 23815501935, 0], [-5752905507515164, 6559328780809, -12915419296, 0, 0, 0, 0, -8300783442], [0, 0, 0, 686775043886, 81266864433, 103624130211, -45158795499, 0], [1093135009631382, 15723198806044, 12187923642, 0, 0, 0, 0, -7361523800], [-4010959786208308, 3183369257403, -33776176704, 0, 0, 0, 0, 5410421229], [0, 0, 0, 294381066544, -178036963617, -125139076275, 12164336763, 0], [0, 0, 0, 1251194821745, 37329578843, 17549653217, -12435357528, 0], [352640478132588, -7034667188653, -18162474208, 0, 0, 0, 0, 5599810219], [0, 0, 0, -957503093798, 1172419333, 101649080335, -28998030711, 0], [0, 0, 0, -6487489193, 263296554345, 21673301463, 18747640512, 0], [0, 0, 0, 880005793722, -123455421719, 109596961515, 7927791117, 0], [4928942564497830, 12569375928020, -5784956434, 0, 0, 0, 0, 8143259128], [-1697744930384596, 22736903780251, -3645998176, 0, 0, 0, 0, -14724108378], [0, 0, 0, 691452790738, 106141529295, -112233103290, 35468406702, 0], [0, 0, 0, -997945057913, -4966362286, 132445864678, 50668095114, 0], [11330077056821682, -4591971712088, 26758865884, 0, 0, 0, 0, 5318190416], [8669772554899364, -1200520846031, 74783847776, 0, 0, 0, 0, -20720281587], [0, 0, 0, 1450093570941, -62773310883, -37425124155, -65170667028, 0], [4585850948464652, -11121847920157, 29127137344, 0, 0, 0, 0, 4763283264], [0, 0, 0, -1433643558856, 22519936641, 53999433804, -59245636578, 0], [0, 0, 0, 801956515287, -48463420392, -168789239133, -15476025294, 0], [-5663701036735878, 37606121302, 32642006089, 0, 0, 0, 0, -27931045864], [-4333656602696770, -11495398532634, 64709612577, 0, 0, 0, 0, -19374355872], [0, 0, 0, -803294458171, -404770013352, -109304107560, -114065257752, 0], [7189262985265956, 29490541298977, -68136553056, 0, 0, 0, 0, 12093394399], [-9270511686599802, 12540806509588, -78754275634, 0, 0, 0, 0, -17571744072], [0, 0, 0, 518885274063, -308063746403, 147572836671, -29340209880, 0], [3095073370608780, -29909243257021, -118884922048, 0, 0, 0, 0, -15909480440], [20391899786160138, 61646902391990, -80055036711, 0, 0, 0, 0, -16028345704], [0, 0, 0, -1544943730443, -410011297941, -447037078539, -756621696, 0], [0, 0, 0, 643175447004, -426603149852, 295744261596, 103160154624, 0], [0, 0, 0, -805570912704, -579353324565, 223232005497, -95182153041, 0], [16010127069609898, 45200802805286, -33259175615, 0, 0, 0, 0, -4277885256], [0, 0, 0, -1130007733959, 150168426084, 409004910612, -174866708340, 0], [-508079426774292, 90491469921059, 11583294432, 0, 0, 0, 0, 10000864265], [0, 0, 0, 2034299167047, 947452956414, -302458796526, -86658126402, 0], [0, 0, 0, 2308106969641, 15802067454, 76798494933, 2220014850, 0], [-14435405931101218, -23028100025162, -86370157543, 0, 0, 0, 0, 43615096608], [0, 0, 0, 289653827032, -438369795527, -348286063796, 18114647598, 0], [13421987834427630, 29660534507238, 124295464353, 0, 0, 0, 0, 26504432928], [44268621165313708, 23452285556139, 33767500896, 0, 0, 0, 0, -28686132372], [0, 0, 0, 1020820051202, -455282920587, 85553678535, -23687222511, 0], [0, 0, 0, 4019003081599, 722321339623, -85204706633, 102699283668, 0], [0, 0, 0, -2919365789582, 896808032625, 344713193899, 86043964365, 0], [0, 0, 0, 773302432864, -697276204828, -638844941648, 90338344824, 0], [8842070104305924, 67571730425569, 86187986816, 0, 0, 0, 0, -53132415312], [0, 0, 0, 4743836124813, -237283290324, -50533215804, 131509942236, 0], [-24018847562311074, 48801175008934, -93210921663, 0, 0, 0, 0, -88242453248], [0, 0, 0, 2367783326484, 956367075003, 389264557344, 164167169298, 0], [0, 0, 0, -1320730646961, 490469441994, 73986163254, 118692207162, 0], [0, 0, 0, 3349758659766, 1798187586457, -18320138421, 291066375597, 0], [-5658887565326396, 43826394533825, -224342571392, 0, 0, 0, 0, 34794813366], [-10541227801596970, 27853808912284, 28142210042, 0, 0, 0, 0, 42041184360], [0, 0, 0, 6913681301648, 1568984375856, -1153809900528, -185094451392, 0], [-39987648058393342, 54218145756032, 69299544640, 0, 0, 0, 0, -80700995232], [-46747633642615284, -69200324337389, -84110452480, 0, 0, 0, 0, -109959104250], [-10819224505469852, -65696578712671, -128636222048, 0, 0, 0, 0, -39215573115], [0, 0, 0, -226065506299, 158478567852, -1566485822004, 51748478868, 0], [21348616089313092, -140497222710719, 98570003456, 0, 0, 0, 0, 143545120746], [-96142599372434562, -10809150439018, 8566489065, 0, 0, 0, 0, 64392720608], [43855784347906642, -15560916153392, -85043184520, 0, 0, 0, 0, 91958665632], [0, 0, 0, -6895272135302, -2350190107499, 214806637519, -43248433719, 0], [1794140539268802, -158717299908000, 141895266832, 0, 0, 0, 0, -74667459008], [0, 0, 0, 87147679193, -4530276108294, -207370424715, 40994418666, 0], [0, 0, 0, 3657334418864, -2173028331249, -220167160155, 141351508323, 0], [0, 0, 0, -2726232374786, -1439385117248, -213296395946, -580202401788, 0], [0, 0, 0, -4956912244024, -1203247043041, 1190374081661, 33100563915, 0], [-68908135045632446, -182147581508136, -45656847516, 0, 0, 0, 0, 123520688784], [-84925599885092532, 25970737422635, 379994998144, 0, 0, 0, 0, -1099917057], [0, 0, 0, -14531443230713, -1049661789090, -84921157230, -275226911682, 0], [0, 0, 0, 2571695418448, -961261005704, 432348678256, 52735693872, 0], [-42934903510741116, 133204896518577, -263400559552, 0, 0, 0, 0, -65881929370], [-8632295454185634, -91338631306378, 452792736313, 0, 0, 0, 0, -106268983296], [20360374025273996, -95277550049045, -48126797824, 0, 0, 0, 0, -97587986643], [75488305131172682, -170609551136042, 234235111817, 0, 0, 0, 0, 44244179928], [0, 0, 0, -3815382087907, 993632170608, -2126152939752, 209053992744, 0], [0, 0, 0, -12209317255575, 352389033073, -1488231150159, 163413654252, 0], [-85949507348470740, 12854738797555, 107107942432, 0, 0, 0, 0, 40528609961], [0, 0, 0, 18396665558679, -1293489280893, 2128626370527, 104923358700, 0], [46244419839381814, -206808731436940, -244297792034, 0, 0, 0, 0, -17329677768], [0, 0, 0, 2206612391930, -965359877220, -1937879779534, 646009785300, 0], [33578286027476490, -120579999013738, 284219580201, 0, 0, 0, 0, 85989783320], [0, 0, 0, 226389841953, 7419443120889, -3914121361431, -17368063572, 0], [0, 0, 0, -8658663298495, -308329391304, -2308570372512, -200431874016, 0], [0, 0, 0, 15038002521755, -5840817741382, -581585477410, -124259928750, 0], [0, 0, 0, 13781063385027, 3319868236920, -178191191937, 584500120602, 0], [-126698229875868774, 143242221421110, 97407891737, 0, 0, 0, 0, -74646091816], [0, 0, 0, -19812313115462, 6266631069546, -2097451153718, -76206056424, 0], [-50336116431715740, -375595477464591, 852687701728, 0, 0, 0, 0, -73847662193], [0, 0, 0, -13504573145740, 1379749090571, -684213386047, 580290610983, 0], [7378566026912238, -108101943245722, 281926496993, 0, 0, 0, 0, -354362729216], [0, 0, 0, 2454837220620, 1734968692200, -2954829447780, 248131283160, 0], [0, 0, 0, -20280517138955, 565213034306, -328521828383, 390364859874, 0], [-35933490716072628, 552555548032483, 560332750528, 0, 0, 0, 0, -144523825642], [0, 0, 0, 14546209317139, -6455850198610, 229742528458, 673233172806, 0], [-54683161670645980, 330369566398065, -359502955296, 0, 0, 0, 0, 387311191833], [0, 0, 0, -772046160544, -1683544551780, 1398912588944, 727081985736, 0], [95185306105163358, -462619064430202, -366393716207, 0, 0, 0, 0, -11585564352], [-153049065202463092, -149009808147293, -52211038144, 0, 0, 0, 0, 327392249316], [0, 0, 0, 9263919974338, -5335261552254, 3315126838866, -169030617384, 0], [124555702372715722, 396025493067526, -43127057647, 0, 0, 0, 0, -344125363080], [0, 0, 0, 39717126183445, 4093457292648, 2665965272400, -625645358928, 0], [-48839830215163476, 139556182912195, 578145315296, 0, 0, 0, 0, -123504800793], [0, 0, 0, 16481013669627, 1098059919273, 1632273078987, -1322149404744, 0], [63445615633262628, 340699305266345, -533681680800, 0, 0, 0, 0, -417127372216], [53952018211409644, 33715086895187, -4719667040, 0, 0, 0, 0, 611317652703], [0, 0, 0, 9416391165081, -11426805573802, -2863337703963, -340982536974, 0], [0, 0, 0, -25934264923482, -969798718003, -2969881200609, -17067648903, 0], [213985353478416786, -503534012542744, -425754879300, 0, 0, 0, 0, -155069504560], [0, 0, 0, 3220260119101, -1311231524901, 3061347455901, 340149420048, 0], [0, 0, 0, 6473054408258, 1952865600707, -1694398787194, -1082184170010, 0], [-277759518162422076, 2359039056665, -1484299595712, 0, 0, 0, 0, 313110820841], [191530402100570188, 191241154865811, -134917730304, 0, 0, 0, 0, -450453660924], [0, 0, 0, 38972345279442, 849097789368, 3949384364826, -890968153620, 0], [0, 0, 0, 39547765269495, 3900584744238, -4568868401838, -1098333498498, 0], [-76693029605192766, -761600897577312, 655687792240, 0, 0, 0, 0, 205170736672], [0, 0, 0, 20502376987445, 12674404773216, 2385825623865, 680286943494, 0], [87607181682360542, -70406570924058, 482536703265, 0, 0, 0, 0, -624251906592], [0, 0, 0, -53326883759571, 161239875096, -1308399505944, -155417133480, 0], [-130758571227395484, -318226333540087, -536775944736, 0, 0, 0, 0, -318864412990], [0, 0, 0, -44688367564233, -8989023929470, -2807210444658, -842603843934, 0], [217098797323636012, 563029605380715, -1271142899616, 0, 0, 0, 0, 366388774608], [0, 0, 0, -17519008321732, -10116076159305, -5490637118307, 883338742827, 0], [-48731073428710874, -212815494801956, -1938423304102, 0, 0, 0, 0, -265475095320], [0, 0, 0, -972788879344, 1015936334480, 8180929270544, -1411157376, 0], [-182583766052321148, 10612741975073, 1246117818624, 0, 0, 0, 0, -392351917636], [0, 0, 0, 33460975409310, -2811204568919, -2867768717277, 211081688853, 0], [0, 0, 0, -70831153633465, -5689803864122, -7169820717622, 363360643782, 0], [-276497080731874182, -112828311018794, -394766280311, 0, 0, 0, 0, 168175377368], [374980755022160836, -163170696124887, -224923606272, 0, 0, 0, 0, -208915721997], [0, 0, 0, 60691632764929, 11511967139844, 5649579946716, 604354067844, 0], [320779086575516430, -411871646787322, -734285473967, 0, 0, 0, 0, 214571110848], [33853275948033260, 567538814707643, 196665917728, 0, 0, 0, 0, -496672055700], [0, 0, 0, -53218871527798, -768004107723, 3833527880583, 2352245368401, 0], [0, 0, 0, -44276028516928, 271375620751, 6769469951957, 48283981491, 0], [183437135524937188, 78988543077857, 182222680480, 0, 0, 0, 0, 694798713153], [-435176025536491474, -123261560027898, -827245023663, 0, 0, 0, 0, 15670555488], [0, 0, 0, 38994084921312, -4452857888410, 884494042776, -2679752575980, 0], [-218029203932824558, -628803252931024, 1324806633352, 0, 0, 0, 0, 651278154624], [0, 0, 0, -41045410107525, -27329822692612, -6003673650201, 1284686196642, 0], [-89502106691855124, -26979032610669, -1863905761632, 0, 0, 0, 0, 449297528439], [0, 0, 0, -18285322796546, -6102094771815, -2860303799813, -2236071299715, 0], [116105226105303070, 909263783016582, -1480252078191, 0, 0, 0, 0, -392472897504], [-651693348176569500, 66812724156273, -1660537378592, 0, 0, 0, 0, 535568739703], [0, 0, 0, 55569187591926, 23432477637309, -5789875770606, -999172553430, 0], [0, 0, 0, 45805730093689, 11139934786524, 98232019453, 3362677508166, 0], [0, 0, 0, -22328180513145, 22227465232638, -18499506660405, 61108437222, 0], [0, 0, 0, 36936583008741, -2459853251276, 1337961749868, -1455591539340, 0], [103014650665228172, -1588712707610733, -52686920832, 0, 0, 0, 0, -815120173206], [0, 0, 0, -43628194927836, -14060011533837, -4413699158064, 1514100351234, 0], [48153870572082506, -469195139616058, -1472357254223, 0, 0, 0, 0, -97261497672], [0, 0, 0, 150329116052966, 1462907046021, -7807504817217, -2897014935207, 0], [0, 0, 0, 121272531388143, -6607602863240, -6631418069733, -2436073102782, 0], [284453906962619586, 1745351277800824, 403204358996, 0, 0, 0, 0, 682388757168], [0, 0, 0, -15112841806961, 18170778465642, 3073604738718, -3131483862894, 0], [-1003378893385535580, -163777850620447, -961785387488, 0, 0, 0, 0, -1224883381773], [-522965499200297202, -749392896021706, -1128240883751, 0, 0, 0, 0, -1565059367136], [-333317523966808692, -1224585419182837, -597858606848, 0, 0, 0, 0, -2248652536359], [0, 0, 0, 105348409894515, -32323046305146, -1613473451886, 471441541566, 0], [0, 0, 0, -38315062201500, 27111264118527, -8659083022899, 1929085669371, 0], [0, 0, 0, -4456246924774, -18194227366585, 78982820750, -4299074969298, 0], [0, 0, 0, 50319550875915, 20078207026542, -1143837419022, -245221995042, 0], [-1216691244783700884, -935745417494829, -1398625913184, 0, 0, 0, 0, -83437659069], [-733333381468303228, -299432632396535, -2340036984064, 0, 0, 0, 0, 1224054941769], [-104555499569198122, -820899555224044, -1408466297906, 0, 0, 0, 0, 1669605130488], [0, 0, 0, 105842706090364, 35156431214571, -5586236095335, -2834934752625, 0], [0, 0, 0, -8078142007132, -44927027491173, 4630824631664, -6579244977870, 0], [-592940440780731036, -2366739573880455, 2299447543584, 0, 0, 0, 0, -526345538136], [427554440084741036, -353160903088893, -4222267932576, 0, 0, 0, 0, 863588114751], [-38867921000257030, 956135300634726, -5303632147551, 0, 0, 0, 0, 257584160184], [-1059986649613570740, 1003452569637819, -1686599706816, 0, 0, 0, 0, -464327654655], [0, 0, 0, 116797685681526, 16196878411877, 11686084118199, 1879126712481, 0], [0, 0, 0, -133827844636183, 8852619438363, 12034278927417, -2927027291784, 0], [0, 0, 0, 216413543904592, -7570276185053, -1208853914543, -4237005329769, 0], [0, 0, 0, -41168849001196, 34490647289223, 9847297294992, -1239750699462, 0], [0, 0, 0, -43615766501775, -1644964438620, -22850588873532, -4128430359972, 0], [636374354221224570, -1806611212236874, -502187903143, 0, 0, 0, 0, -1451381809832], [113021700246366404, -328823715994279, 7622513964736, 0, 0, 0, 0, 1251339636417], [0, 0, 0, 51509045848783, -14932671450225, 584413441383, -7757478141468, 0], [545583926598517694, 1432086368499974, -2523426100655, 0, 0, 0, 0, 95246929056], [-840562287539925084, -4505025577350167, 2846557170656, 0, 0, 0, 0, 1272158765844], [0, 0, 0, -64040593189364, -26555649262038, -8323244870652, -9862109092620, 0], [1881323670736149826, 937296725113824, 3145203007056, 0, 0, 0, 0, 375676419264], [-707908372644019278, 3541023014685424, 3064952183464, 0, 0, 0, 0, 512128527584], [-478112206596137372, -982326464403559, -1060328162528, 0, 0, 0, 0, 1231013647908], [-35007419988934906, 599148361274044, -7546201764310, 0, 0, 0, 0, -1190104659480], [0, 0, 0, 198708328891055, 15904976647854, -23607803077134, 6728069946846, 0], [0, 0, 0, 50169357921280, 37729180052526, 14055851953624, 4298460474564, 0], [-21273781439719818, -352062155605452, 8358670082430, 0, 0, 0, 0, -298542425928], [-1548452826383706710, -1102033558446010, -4193218563599, 0, 0, 0, 0, 3643790751672], [385593803006268548, -64012788096639, 537720554112, 0, 0, 0, 0, -174074553432], [119097738628148012, -2593243377619245, 1474764535968, 0, 0, 0, 0, -4685930474835], [0, 0, 0, 92287672727694, 23205409410849, 16975521484890, 3455547951282, 0], [0, 0, 0, -79235105228741, 128188801377066, -16400898606642, -658264903710, 0], [0, 0, 0, -192661625691384, -2657826088273, 12107045200821, -10226029189677, 0], [0, 0, 0, 257935798746073, -40855240382520, 2436229645584, -3242782291728, 0], [0, 0, 0, 159736218598988, 85319439836338, -64451288855836, -560014929180, 0], [-5393384944940412, 1520274748863929, 2038397712576, 0, 0, 0, 0, 251624197535], [849179769862412428, 4414807939841027, -10798032699200, 0, 0, 0, 0, 175300006368], [-2728817242094941140, 1804127992770379, -5729927723168, 0, 0, 0, 0, 1664635268084], [0, 0, 0, -163532212074183, 28839214782944, -29125498344504, 11895416619000, 0], [2389874405813628834, 2638825428030816, -1931515375216, 0, 0, 0, 0, 616900790816], [1165233012590664766, -1056537709269194, 1775661840857, 0, 0, 0, 0, -1274812454112], [0, 0, 0, -236141539557852, -14502510627291, 39698429704440, -984323838402, 0], [0, 0, 0, -101600936503223, -10492028946476, 12171810124996, 10570968785244, 0], [-1337199382732316250, -1973736297277988, 6511212109402, 0, 0, 0, 0, -1607682392920], [0, 0, 0, 17880979407860, 45953806766391, 1787404207725, -5019643962405, 0], [0, 0, 0, -115767762987007, 41383634198842, -37329306412483, -8596390274982, 0], [0, 0, 0, 135493140965080, 21243591550755, -23421774979719, 14211647945775, 0], [-338742935984989116, 174856110768065, -5028631563648, 0, 0, 0, 0, -875308830766], [0, 0, 0, -110157392820735, -19233059763336, -59545244301720, 2445042227160, 0], [4124302057019615692, -281707633834725, 4041991321536, 0, 0, 0, 0, -622466105751], [0, 0, 0, -47457958886302, 87874500118704, -71101586992566, -772295752740, 0], [0, 0, 0, -248115667578281, 74910077176026, -3244556407866, 899969964330, 0], [1064463682242292484, 7155937730421841, 1650716246336, 0, 0, 0, 0, 3003359325726], [2167430321645609302, 39239563436180, -6586103068274, 0, 0, 0, 0, -2726298596616], [0, 0, 0, -114989649908276, -2366930362245, -34551950148375, -9996322208577, 0], [0, 0, 0, -327697032134442, -23512303841100, -43411668248034, 1977666328812, 0], [0, 0, 0, -283424384012829, -107084397457346, -2417797619166, 8952324527406, 0], [-669994028249159442, -837006549016394, -4343861175527, 0, 0, 0, 0, 6818409381440], [0, 0, 0, -1002513013024, 14270621694702, 60316041594552, 4249782856644, 0], [1680733613110339788, -5773565829465053, 11126791422016, 0, 0, 0, 0, -8477014746910], [-1089150475153263318, -6330280662682266, -4949768265951, 0, 0, 0, 0, -2267375511624], [0, 0, 0, -460790924656643, -58140779544387, 26261708764869, 9157006752300, 0], [0, 0, 0, 564719892175778, 8882100046205, -10077900087841, 14293328626617, 0], [-1858384031855861922, 3018182550593430, -3294486720535, 0, 0, 0, 0, 4205348705600], [0, 0, 0, -367920998279940, -62623016946093, -8597294417784, -19978052802222, 0], [-844459568164210260, -4188012897192709, -5459711650400, 0, 0, 0, 0, 4742407096494], [1538394400335656260, 4549287566469361, -1827376573504, 0, 0, 0, 0, -2348134654560], [1100949432921828862, -4586173887647434, -12056594485031, 0, 0, 0, 0, -150582392160], [0, 0, 0, 356922414189508, -89942871628389, 44633360120505, -2267211056529, 0], [0, 0, 0, -601690118709179, 32052675668176, 59621445736009, 10122585664518, 0], [421222964234983462, -5498511666827564, -9358610223634, 0, 0, 0, 0, 1547450148216], [-2615706049245539004, -1830455537988663, -16453607245056, 0, 0, 0, 0, 1897021488411], [1190780896781270348, -10869094075760901, -2811829776576, 0, 0, 0, 0, 3557103546729], [0, 0, 0, -275543315326272, 51794999742387, -59896496389092, 2067783219210, 0], [0, 0, 0, 442906746136120, 89704685941095, 39678879285237, 7336560597267, 0], [0, 0, 0, -262569900690941, 3878633565040, 4493624526751, 585043735914, 0], [0, 0, 0, -847834122123835, 19120413552788, -22245142610668, -4773071594868, 0], [-1883139798123173148, 6308522238628297, 27357568387424, 0, 0, 0, 0, -183991522314], [0, 0, 0, 506432025302426, 51890043872271, 85828806359598, -18279827910690, 0], [-1632504470470742782, -6326701683540712, 10780919416132, 0, 0, 0, 0, 4871855957136], [1125925009995125994, 13824921564383558, -8729666774159, 0, 0, 0, 0, 4704232590264], [-4365027140174487322, 7154918178100828, 10318768104218, 0, 0, 0, 0, 3714381568104], [0, 0, 0, 296639556284801, -69398943392928, 20059146023496, 12436544955768, 0], [-377467895030781258, -4466183312566468, 11338301175018, 0, 0, 0, 0, -529318374616], [0, 0, 0, 357700714940695, -114569862854980, -35308359911885, 5926653245610, 0], [-4969374371687256126, -2177903113992680, -23158900193596, 0, 0, 0, 0, 1115463625104], [822080840279108036, 8832969738910321, -2571220534336, 0, 0, 0, 0, -3535831176468], [0, 0, 0, 156526109080361, 123541371491664, -58105393522179, -13147313453250, 0], [0, 0, 0, -121682905111692, -15154522644795, 90652887936264, 16481034607710, 0], [0, 0, 0, 837791202759478, -102049022568259, 104916822562327, 16309799176641, 0], [2608998791306530924, 2902646894671675, 4806834576800, 0, 0, 0, 0, -10597367007648], [0, 0, 0, 415130522956300, -72806236773186, 129958760535828, -4483266792564, 0], [1004873338727374370, 5870509243890360, 9903631190580, 0, 0, 0, 0, 8872459537200], [0, 0, 0, -505962685129836, 67598796284871, 4863006640365, 3174300138075, 0], [-3613901594027213940, -3249709356745349, 10939260305600, 0, 0, 0, 0, 1888360007559], [4575658062139603940, 909583472708761, 12648996559136, 0, 0, 0, 0, 8722215221400], [0, 0, 0, -387258782750923, -105261100346097, 156669505100037, -16623455599944, 0], [6443808187005178438, -6226725477003012, -21008841931638, 0, 0, 0, 0, 2973306240936], [0, 0, 0, 384058469617796, 102052889389204, -136260662141596, 3169604989776, 0], [14731380696580278, -730527121123020, 22360877695486, 0, 0, 0, 0, -785980103048], [-1906120234417558708, -6267060718851405, -10371939197952, 0, 0, 0, 0, -192872040144], [0, 0, 0, 67638645198408, -182111793036057, -33420022173099, -49118513345613, 0], [0, 0, 0, -118696380555301, -144170744996238, 32328956846222, 13266967919010, 0], [-4995055442895052902, -6821484944897754, 7838091198401, 0, 0, 0, 0, -2122138496776], [0, 0, 0, -44571158613242, -198412580146236, 37099428464206, -7355481920532, 0], [3785401404193271718, 2583204689923316, 9284724357278, 0, 0, 0, 0, -2209738778120], [0, 0, 0, -358544680597047, -256549624704624, 20647818306384, 8866155286320, 0], [0, 0, 0, -238787930025667, -288160121400510, -24948145003447, -44189710107246, 0], [0, 0, 0, -513845468311856, 84316765923223, 38698389592285, 31157441485803, 0], [2082987500061479658, 8289534829646486, 11588133013033, 0, 0, 0, 0, -5189236903080], [-4227471463446035932, -13271047915315991, 8722791150176, 0, 0, 0, 0, -2977105040640], [-8403013027576466940, -7713673724405783, -14836135079936, 0, 0, 0, 0, -1333568755879], [5636155579984358770, -1674859477776848, -43543858591864, 0, 0, 0, 0, 4189394681472], [0, 0, 0, -400726599157156, -316542193741677, 62577525914169, 22162870520943, 0], [-5125336041093342036, 3481709636778475, -16210904352928, 0, 0, 0, 0, -9705989434812], [2349345849867377732, -4584216553092591, 47023451487168, 0, 0, 0, 0, -8853213887028], [-4792857695385585602, 3740966642311238, 1054418109745, 0, 0, 0, 0, 7947341999040], [0, 0, 0, 107129205177436, 55930120547043, -129992447152383, 52258836133479, 0], [0, 0, 0, -398266219162304, -297480154979580, -31964274888432, 1468606536120, 0], [0, 0, 0, 325504642422761, -2906439034246, 32889405407813, 55984425096330, 0], [7447759455828382218, -19023229654497898, -4993618665303, 0, 0, 0, 0, 17745521586584], [0, 0, 0, 196344177876873, 113766563733741, 37282670275329, 42347287633716, 0], [0, 0, 0, -489016958769260, 252598231279695, 35009934248109, -22109654577381, 0], [0, 0, 0, 60719339636218, 511760288263917, -31829285970017, 36498022934265, 0], [0, 0, 0, -596168933765140, 135278189936433, -64205382786480, 15251642441622, 0], [-6528487354167985044, -6148780820495861, 24081771080288, 0, 0, 0, 0, -3202186474518], [-1333202887729853962, -8212955103808324, -22456394170070, 0, 0, 0, 0, -10688967509784], [0, 0, 0, -1119157817754486, 45928480815825, 71023136612379, -2392377770019, 0], [-14138674158397898652, -5064106425134847, 27926744187296, 0, 0, 0, 0, -2538781964527], [7564063587861954030, 3298028670966118, 9091536296545, 0, 0, 0, 0, -15882078053248], [-919093448849632468, -4120286357233565, 58976749633376, 0, 0, 0, 0, -995023051473], [0, 0, 0, 585953665304057, 193672617570903, -119726817657927, -53117413477728, 0]]
